[EFI] Increase EFI FDT table size

Some vim3 devices have huge MMC device tree that needs to be appended as
a ZBI item. We currently pass these ZBI items via EFI device tree in the
configuration table. Increase the size so that it can accomodate these
devices.

Change-Id: I92cd0c4f6bf16d3bf7bc802bd107bfff38c4f1c9
Reviewed-on: https://turquoise-internal-review.googlesource.com/c/third_party/u-boot/+/912510
Reviewed-by: Sergii Parubochyi <sergiip@google.com>
GitOrigin-RevId: 3cf11dcfaa1e8b416efcd8491e374b4fa691f93c
diff --git a/common/cmd_bootefi.c b/common/cmd_bootefi.c
index ca83202..77c7455 100644
--- a/common/cmd_bootefi.c
+++ b/common/cmd_bootefi.c
@@ -198,11 +198,11 @@
 	}
 
 	/*
 	 * Give us at least 12 KiB of breathing room in case the device tree
 	 * needs to be expanded later.
 	 */
 	fdt = *fdtp;
-	fdt_pages = efi_size_in_pages(fdt_totalsize(fdt) + 0x3000);
+	fdt_pages = efi_size_in_pages(fdt_totalsize(fdt) + 256 * 1024);
 	fdt_size = fdt_pages << EFI_PAGE_SHIFT;
 
 	ret = efi_allocate_pages(EFI_ALLOCATE_ANY_PAGES,
@@ -198,11 +198,11 @@
 
 	/*
-	 * Give us at least 12 KiB of breathing room in case the device tree
+	 * Give us at least 256 KiB of breathing room in case the device tree
 	 * needs to be expanded later.
 	 */